==> krecipes-trinity_14.0.4.orig.tar.xz: krecipes-trinity-14.0.4/krecipes/src/dialogs/selectunitdialog.h <==
/***************************************************************************
*   Copyright (C) 2003 by                                                 *
*   Unai Garro (ugarro@users.sourceforge.net)                             *
*   Cyril Bosselut (bosselut@b1project.com)                               *
*   Jason Kivlighn (jkivlighn@gmail.com)                                  *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
***************************************************************************/

#ifndef SELECTUNITDIALOG_H
#define SELECTUNITDIALOG_H

#include <ntqwidget.h>
#include <ntqlayout.h>
#include <ntqpushbutton.h>
#include <ntqgroupbox.h>
#include <ntqvbox.h>

#include <tdelistview.h>
#include <kdialogbase.h>

#include "datablocks/unit.h"

/**
@author Unai Garro
*/
class SelectUnitDialog : public KDialogBase
{
public:
	typedef enum OptionFlag { ShowEmptyUnit, HideEmptyUnit } ;

	SelectUnitDialog( TQWidget* parent, const UnitList &unitList, OptionFlag = ShowEmptyUnit );

	~SelectUnitDialog();

	int unitID( void );

private:
	//Widgets
	TQGroupBox *box;
	TDEListView *unitChooseView;
	OptionFlag m_showEmpty;

	void loadUnits( const UnitList &unitList );

};

#endif

==> krecipes-trinity-14.0.11.tar.xz: krecipes-trinity-14.0.11/krecipes/src/dialogs/selectunitdialog.h <==
/***************************************************************************
*   Copyright (C) 2003 by                                                 *
*   Unai Garro (ugarro@users.sourceforge.net)                             *
*   Cyril Bosselut (bosselut@b1project.com)                               *
*   Jason Kivlighn (jkivlighn@gmail.com)                                  *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
***************************************************************************/

#ifndef SELECTUNITDIALOG_H
#define SELECTUNITDIALOG_H

#include <ntqwidget.h>
#include <ntqlayout.h>
#include <ntqpushbutton.h>
#include <ntqgroupbox.h>
#include <ntqvbox.h>

#include <tdelistview.h>
#include <kdialogbase.h>

#include "datablocks/unit.h"

/**
@author Unai Garro
*/
class SelectUnitDialog : public KDialogBase
{
public:
	enum OptionFlag { ShowEmptyUnit, HideEmptyUnit } ;

	SelectUnitDialog( TQWidget* parent, const UnitList &unitList, OptionFlag = ShowEmptyUnit );

	~SelectUnitDialog();

	int unitID( void );

private:
	//Widgets
	TQGroupBox *box;
	TDEListView *unitChooseView;
	OptionFlag m_showEmpty;

	void loadUnits( const UnitList &unitList );

};

#endif
